@@ -1,9 +1,12 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 '''
 simple kml export for logfiles
 Thomas Gubler <thomasgubler@gmail.com>
 '''
+from __future__ import print_function
+
+from builtins import range
 
 from argparse import ArgumentParser
 import simplekml
@@ -11,6 +14,7 @@ from pymavlink.mavextra import *
 from pymavlink import mavutil
 import time
 import re
+import os
 
 mainstate_field = 'STAT.MainState'
 position_field_types = [  # Order must be lon, lat, alt to match KML
@@ -19,8 +23,9 @@ position_field_types = [  # Order must be lon, lat, alt to match KML
 ]
 
 colors = [simplekml.Color.red, simplekml.Color.green, simplekml.Color.blue,
-          simplekml.Color.violet, simplekml.Color.yellow,
-          simplekml.Color.orange]
+          simplekml.Color.violet, simplekml.Color.yellow, simplekml.Color.orange,
+          simplekml.Color.burlywood, simplekml.Color.azure, simplekml.Color.lightblue,
+          simplekml.Color.lawngreen, simplekml.Color.indianred, simplekml.Color.hotpink]
 
 kml = simplekml.Kml()
 kml_linestrings = []
